Single source of truth for integer-to-name mapping. All code paths that convert method integers to strings should call this function.
Single source of truth for integer-to-name mapping. All code paths that convert method integers to strings should call this function.