Computes the mean for each condition from a stacked data matrix where data is organized as subjects within conditions (n_subj * n_cond rows).
Computes the mean for each condition from a stacked data matrix where data is organized as subjects within conditions (n_subj * n_cond rows).