Validates the PLS specification and executes the analysis. This is the final step in the builder pattern.
Arguments
- spec
A
pls_specobject- progress
Logical, show progress messages
- ...
Additional arguments passed to
pls_analysis()
Validates the PLS specification and executes the analysis. This is the final step in the builder pattern.
A pls_spec object
Logical, show progress messages
Additional arguments passed to pls_analysis()