Computes brain scores by projecting the data matrix onto the saliences. Brain scores indicate how strongly each observation expresses each latent variable pattern.
Computes brain scores by projecting the data matrix onto the saliences. Brain scores indicate how strongly each observation expresses each latent variable pattern.